@@ -3,10 +3,12 @@ import logging
 import asyncio
 import argparse
 import textwrap
+
 from domain_email_records import __title__
 from domain_email_records import __version__
 from domain_email_records.domain_email_records import DomainEmailRecords
 from domain_email_records.domain_email_records import DomainEmailRecordsException
+from domain_email_records import DOMAIN_RECORD_TYPES_VALID
 
 
 def main():
@@ -23,17 +25,19 @@ def main():
         domain_email_records = DomainEmailRecords(
             chunk_size=args.chunk,
             csv_column=args.csv_column,
-            max_query_seconds=args.timeout,
+            query_timeout=args.timeout,
+            nameservers=args.nameservers,
             logging_level=logging_level,
         )
         if args.filename:
-            domains = domain_email_records.read_domains_file(filename=args.filename, csv_column=args.csv_column)
+            domains = domain_email_records.read_domain_list_file(filename=args.filename, csv_column=args.csv_column)
         else:
             domains = args.domains
 
-        # asyncio.run(domain_email_records.lookups(domains=domains, output=args.out))
         eventloop = asyncio.get_event_loop()
-        eventloop.run_until_complete(domain_email_records.lookups(domains=domains, output=args.out))
+        eventloop.run_until_complete(
+            domain_email_records.lookups(domains=domains, lookup_types=args.types, output=args.out)
+        )
         eventloop.close()
 
     except KeyboardInterrupt:
@@ -84,13 +88,34 @@ def __argparse() -> argparse.Namespace:
         help="Filename to save JSON formatted output to (default: stdout)",
     )
     parser.add_argument(
-        "-t",
+        "-T",
         "--timeout",
         metavar="<seconds>",
         required=False,
         type=int,
-        default=5,
-        help="Timeout seconds per domain-record query (default: 5)",
+        default=10,
+        help="Timeout seconds per domain-record query (default: 10)",
+    )
+    parser.add_argument(
+        "-n",
+        "--nameservers",
+        metavar="<address>",
+        required=False,
+        type=str,
+        nargs="*",
+        default=None,
+        help="Space separated list of alternate nameservers (default: system nameservers)",
+    )
+    parser.add_argument(
+        "-t",
+        "--types",
+        metavar="<qtype>",
+        required=False,
+        type=str,
+        nargs="*",
+        default=["ns", "apex", "mx", "spf", "dmarc"],
+        help=f"Space separated list lookup types to collect (default: ['ns', 'apex', 'mx', 'spf', 'dmarc']); "
+        f"also 'txt' type is available",
     )
     parser.add_argument(
         "-c",
@@ -98,16 +123,16 @@ def __argparse() -> argparse.Namespace:
         metavar="<size>",
         required=False,
         type=int,
-        default=1000,
-        help="Chunk size per async loop to resolve together (default: 1000)",
+        default=500,
+        help="Chunk size per async loop to resolve together (default: 500)",
     )
 
-    direct_list_parser = parser.add_argument_group(title="direct")
+    direct_list_parser = parser.add_argument_group(title="domains-by-cli")
     direct_list_parser.add_argument(
         "-d", "--domains", metavar="<domain>", nargs="*", help="Space separated list of domain names to query"
     )
 
-    file_list_parser = parser.add_argument_group(title="filename")
+    file_list_parser = parser.add_argument_group(title="domains-by-file")
     file_list_parser.add_argument(
         "-f",
         "--filename",
@@ -116,6 +141,7 @@ def __argparse() -> argparse.Namespace:
         help="Filename with list of domains to use; plain list text file -or- a comma-separated CSV file list.",
     )
     file_list_parser.add_argument(
+        "-col",
         "--csv-column",
         metavar="<col>",
         required=False,
